@@ -4,7 +4,7 @@ import jax.numpy as jnp
 from fortuna.typing import Array
 
 
-class Linear(nn.Module):
+class LinearModel(nn.Module):
     """
     A linear model.
 
