@@ -38,7 +38,6 @@ class Predictive(WithRNG):
         distribute: bool = True,
         **kwargs
     ) -> jnp.ndarray:
-
         r"""
         Estimate the predictive log-probability density function (a.k.a. log-pdf), that is
 
@@ -341,7 +340,7 @@ class Predictive(WithRNG):
         if rng is None:
             rng = self.rng.get()
 
-        return self._loop_fun_through_inputs_loader(
+        return self._loop_ensemble_fun_through_inputs_loader(
             self._sample_batched_calibrated_outputs,
             inputs_loader,
             n_output_samples,
@@ -694,7 +693,7 @@ class Predictive(WithRNG):
                 calib_mutable=_sample.calib_mutable,
             )
             _curr_sum += mean
-            _curr_sum_sq += mean ** 2
+            _curr_sum_sq += mean**2
             return _curr_sum, _curr_sum_sq
 
         curr_sum, curr_sum_sq = fun(0, (0.0, 0.0))
@@ -871,3 +870,31 @@ class Predictive(WithRNG):
             )
         fun2 = jit(fun2)
         return jnp.concatenate([fun2(batch) for batch in data_loader], 0)
+
+    def _loop_ensemble_fun_through_inputs_loader(
+        self,
+        fun: Callable,
+        inputs_loader: InputsLoader,
+        n_posterior_samples: int,
+        rng: PRNGKeyArray,
+        distribute: bool = True,
+        **kwargs
+    ) -> Array:
+        if distribute and jax.local_device_count() <= 1:
+            distribute = False
+
+        def fun2(_inputs):
+            return fun(_inputs, n_posterior_samples, rng, **kwargs)
+
+        if distribute:
+            inputs_loader = DeviceDimensionAugmentedInputsLoader(inputs_loader)
+            fun2 = pmap(fun2)
+            return jnp.concatenate(
+                [
+                    self.likelihood._unshard_array(fun2(inputs))
+                    for inputs in inputs_loader
+                ],
+                1,
+            )
+        fun2 = jit(fun2)
+        return jnp.concatenate([fun2(inputs) for inputs in inputs_loader], 1)
